function [x,p] = hsimulate(x,p,T,dt,f,args);
  %
  % this is a general hamiltonian dynamics simulator, written with double pendulum
  %
  % hsimulate(x,p,T,dt,f,args)
  %
  % simulates the equations
  %  [ dx/dt , dp/dt ] = f(x,p,t)
  % using the leapfrog method
  %
  % in steps of dt from t=0 to T
  %
  % the structure args.* contains options
  %
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  
  [N,D] = size(x) ;
  [Np,Dp] = size(p) ;
  if N ~= Np | D ~=Dp
    disp ' warning, x and p different dimensions ' , N , D , Np , Dp  
  end
  
  period = round(args.Tperiod/dt) ;
  
  % initialize gradient 
  t = 0 ;
  findghVKH ;
  
  picturedefns
  if args.refresh
    setupfigures %# includes the creation of xwindow
  end
  %# if_ doplots2 below then use setupfigures2 here also
  setupfigures2
  
  if args.wait %# pause to show the figures 
    disp 'press key'
    pause
    disp 'rolling'
  end
  
  epsilon = dt ;
  its = 0 ; 
  for t = dt : dt : T
    oldx = x ; oldp = p ;
    if args.leapfrog 
      p = p + 0.5 * epsilon * g ; % # g = dH/dx
      findghVKH ;
      x = x + epsilon * h       ; % # h = dH/dp
      findghVKH ;
      p = p + 0.5 * epsilon * g ;
      findghVKH ;
    else
      p = p + epsilon * g ; % # g = dH/dx
      x = x + epsilon * h ; % # h = dH/dp
      findghVKH ;
    end
    %
    % plotting time
    %
    if ( mod(its,period)<1 )
      doplots2 ;
    end
    % maintain poincare section
    if args.poincare
      for n = 1 : N
	if x(n,1) > 0.0 & oldx(n,1) < 0.0
	  %#	addpoincarepoint(x(n,2),p(n,2),n) ;
	  s = x(n,1) ; t = oldx(n,1) ;
	  div = s+t ;
	  s = s / div ; t = t/div ;
	  xx=[t,s] * [ x(n,2); oldx(n,2)] ;
	  pp=[t,s] * [ p(n,2); oldp(n,2)] ; 
	  addpoincarepoint ;
	end
      end
    end
    its = its + 1 ; 
  end
  
  
  



