function [p] = makecircularp(x,m);
  %# computes the value of p required to put a particle of mass m
  %# in a circular orbit with a particle (sun) of mass 1 starting
  %# from x. (assuming that the sun will compensate and sit in
  %# the right opposite place)
  %#
  %# m x = - M X
  %# R = (x+|X|)
  %# m / R^2 = m p^2 / x
  %# p^2 = x / R^2 = 1/x * 1/(1+m)**2 

  mtot = m + 1 ;
  xsquared = sum( x.^2 ) ;
  xmag =  sqrt( xsquared ) ;
  xhat = x / xmag ; 
  psquared = 1.0/ ( xmag * mtot^2 ) ;
  pmag = sqrt( psquared ) ;
  p = pmag * [ -xhat(2) , xhat(1) ] ; 
  


