function [xt,pt] = maketrojan(x,p,m);
  %# computes the value of xt,pt required to put a trojan
  %# in a circular orbit with a jupiter of mass m at x,p
  %# (assuming that the sun will sit in
  %# the right opposite place to jupiter). The centre of mass of solar system is at 0.0.
  %#
  %# m x = - M X
  %# R = (x+|X|)
  %# m / R^2 = m p^2 / x
  %# p^2 = x / R^2 = 1/x * 1/(1+m)**2 

  theta = -pi / 3.0 ;
  
  mtot = m + 1 ;
  xsun = - x * m ;

  xsquared = sum( x.^2 ) ;
  xmag =  sqrt( xsquared ) ;
  xhat = x / xmag ; 
  psquared = sum( p.^2 ) ;
  pmag =  sqrt( psquared ) ;
  phat = p / pmag ; 

  rhat = xhat * mtot ; 

  R = [ cos(theta) -sin(theta) ; sin(theta) cos(theta) ] ;
  xt = xsun +( x - xsun )* R  ;

  xtsquared = sum( xt.^2 ) ;
  xtmag =  sqrt( xtsquared ) ;
  xthat = xt / xtmag ; 

  omega = pmag / xmag ; 
  ptmag = omega * xtmag ; 
  pt = ptmag * [ -xthat(2) , xthat(1) ] ; 
  


