function [x,p] = carefulsimulate(x,p,m,T,dt,args);
%
% carefulsimulate(x,p,T,dt,f,args)
%
% simulates the equations
%  dx/dt =  v
%  with occasional collisions
% by predicting the next collision
%
% the structure args.* contains options
%
% recommended plotting time is the same as dt. 
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[N,D] = size(x) ;
[Np,Dp] = size(p) ;
if N ~= Np | D ~=Dp
  disp ' warning, x and p different dimensions '
end

period = round(args.Tperiod/dt) ;
if (period<1) period = 1 ; end
t = 0 ;

picturedefns
if args.refresh
  setupfigures %# includes the creation of xwindow
end
setupfigures2

if args.wait
  disp 'press key'
  pause
end

leftwall = 0.0 ; 
rightwall = args.length ; 
its = 0 ;

while (t<T)
  %# find all times to next impacts...
  BIG = T ;
  fudge = 1.0000001 ; %# factor to go beyond the next collision.
  for i=1:D+1
    if ( i == 1 )
      xleft = 0.0 ; pleft = 0.0 ; 
    else
      xleft= x(i-1) ; pleft = p(i-1) ; 
    end
    if ( i == D+1 )
      xright = args.length ; pright = 0.0 ; 
    else
      xright = x(i) ; pright = p(i) ; 
    end
    dp = pright - pleft ;
    if dp >= 0.0
      timetocontact(i) = BIG ;
    else
      timetocontact(i) = (xright-xleft)/(-dp) ;
    end
  end
  ttcmin = min(timetocontact) ;
  if ttcmin > dt 
    epsilon = dt ;
  else
    epsilon = ttcmin * fudge ;
  end

  t = t + epsilon ; 
  xold = x ; 
  x = x + epsilon * p     ;
  
  %#  check for collisions among balls
  [y,index] = sort(x) ;
  for i=1:D-1
    if ( index(i+1) < index(i) )
      %#      disp i,'bonk' ; 
      [x(i),x(i+1)] =  collide( x(i),x(i+1) , xold(i),xold(i+1) ) ;
      [p(i),p(i+1)] =  bounce( p(i),p(i+1) , m(i),m(i+1) ) ;
      [y,index] = sort(x) ;
      i=0 ; %# go back to the beginning
    end
  end
  
  %#  check for collisions with walls
  %# compact version:
  %#  p = ( x < leftwall ) ? abs(p) : p ;
  %#  x = ( x < leftwall ) ? 2*leftwall - x : x ;
  
  %#  p = ( x > rightwall ) ? -1 * abs(p) : p ;
  %#  x = ( x > rightwall ) ? 2*rightwall - x : x ;
  for i=1:D
    if x(i) < leftwall
      %#      disp 'left bonk' ; 
      p(i) = abs(p(i)) ; x(i) = 2*leftwall - x(i) ;
    else if x(i) > rightwall
	%#      disp 'right bonk' ; 
	p(i) = -abs(p(i)) ; x(i) = 2*rightwall - x(i) ;
      end
    end
    
    %
    % plotting time
    %
    if ( mod(its,period)<1 )
      doplots ;
    end
    its = its + 1 ; 
  end
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
end
  
