function [x,p] = simulate(x,p,m,T,dt,args);
%
% simulate(x,p,T,dt,f,args)
%
% simulates the equations
%  dx/dt =  v
%  with occasional collisions
%
% in steps of dt from t=0 to T
%
% the structure args.* contains options
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[N,D] = size(x) ;
[Np,Dp] = size(p) ;
if N ~= Np | D ~=Dp
  disp ' warning, x and p different dimensions '
end

%				# see forbit.m for gradient calcn
period = round(args.Tperiod/dt) ;

t = 0 ;

picturedefns
if args.refresh
  setupfigures %# includes the creation of xwindow
end
setupfigures2

if args.wait
  disp 'press key'
  pause
end

leftwall = 0.0 ; 
rightwall = args.length ; 
epsilon = dt ;
its = 0 ;

for t = dt : dt : T
  xold = x ; 
  x = x + epsilon * p     ;

  [y,index] = sort(x) ;
  for i=1:D-1
    if ( index(i+1) < index(i) )
      %#      disp i,'bonk' ; 
      [x(i),x(i+1)] =  collide( x(i),x(i+1) , xold(i),xold(i+1) ) ;
      [p(i),p(i+1)] =  bounce( p(i),p(i+1) , m(i),m(i+1) ) ;
      [y,index] = sort(x) ;
      i=0 ; %# go back to the beginning
    end
  end

  %#  check for collisions
  %# compact version:
  %#  p = ( x < leftwall ) ? abs(p) : p ;
  %#  x = ( x < leftwall ) ? 2*leftwall - x : x ;
  
  %#  p = ( x > rightwall ) ? -1 * abs(p) : p ;
  %#  x = ( x > rightwall ) ? 2*rightwall - x : x ;
  for i=1:D
    if x(i) < leftwall
%#      disp 'left bonk' ; 
      p(i) = abs(p(i)) ; x(i) = 2*leftwall - x(i) ;
    else if x(i) > rightwall
%#      disp 'right bonk' ; 
      p(i) = -abs(p(i)) ; x(i) = 2*rightwall - x(i) ;
    end
  end

%
  % plotting time
  %
  if ( mod(its,period)<1 )
    doplots ;
  end
  its = its + 1 ; 
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



end
