function [x,p] = hsimulate(x,p,T,dt,f,args);
  %
  % this is a general hamiltonian dynamics simulator, written with double pendulum
  %
  % hsimulate(x,p,T,dt,f,args)
  %
  % simulates the equations
  %  [ dx/dt , dp/dt ] = f(x,p,t)
  % using the leapfrog method
  %
  % in steps of dt from t=0 to T
  %
  % the structure args.* contains options
  %
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  
  [N,D] = size(x) ;
  [Np,Dp] = size(p) ;
  if N ~= Np | D ~=Dp
    disp ' warning, x and p different dimensions ' , N , D , Np , Dp  
  end
  
  period = round(args.Tperiod/dt) ;
  
  % initialize gradient 
  t = 0 ;
  findghVKH ;
  
  picturedefns
  if args.refresh
    setupfigures %# includes the creation of xwindow
  end
  %# if_ doplots2 below then use setupfigures2 here also
  setupfigures2
  
  if args.wait %# pause to show the figures 
    disp 'press key'
    pause
    disp 'rolling'
  end
  
  epsilon = dt ;
  its = 0 ;
  historyrow = 1 ; 
  if ( args.read == 0 ) %# prepare to write
    xr = reshape ( x , 1 , 2*N ) ; 
    pr = reshape ( p , 1 , 2*N ) ; 
    xhistory = xr ; 
    phistory = pr ;
    Ehistory = [H' V' K'] ;
  else %# read in
    load ( args.file ) ; %# reads in xhistory and phistory and Ehistory
    [Rowsmax , cols] = size(xhistory) ;
    disp 'Read in history'
    [Rowsmax , cols]
    get_next_xp
  end
  %# the following allows you to plot a given file at whatever plotting resolution (controlled by period) you wish.
  for t = dt : dt : T
    oldx = x ; oldp = p ;
    historyrow = historyrow + 1 ; 
    if ( args.read == 0 ) %# work it out
      if args.leapfrog 
	p = p + 0.5 * epsilon * g ; % # g = dH/dx
	findghVKH ;
	x = x + epsilon * h       ; % # h = dH/dp
	findghVKH ;
	p = p + 0.5 * epsilon * g ;
	findghVKH ;
      else
	p = p + epsilon * g ; % # g = dH/dx
	x = x + epsilon * h ; % # h = dH/dp
	findghVKH ;
      end
      %# prepare to write
      xr = reshape ( x , 1 , 2*N ) ; 
      pr = reshape ( p , 1 , 2*N ) ; 
      xhistory(historyrow,:) = xr ; 
      phistory(historyrow,:) = pr ;
      Ehistory(historyrow,:) = [H' V' K'] ;
    else
      get_next_xp
    end
    %
    % plotting time
    %
    if ( mod(its,period)<1 )
      doplots2 ;
    end
    maintain_poincare_section
    its = its + 1 ; 
  end
  if ( args.read == 0 ) %# write
    save ( args.file, 'xhistory','phistory','Ehistory' ) ;
  end
  
  
  
  %# end function 


