function mode(A,x0,x1,dt,T1,T2,pausetime)
  %# A is a N*N matrix, which should have N real eigenvalues.
  %#  it need not be symmetric
  %# x0 and x1 are initial conditions of x and its velocity
  %# right hand column will contain
  %# the initial conditions
  %# and the reconstruction

  %# whether to show the points 0 and N+1 as having coordinate zero
  %# (good if in fact it is a wall-constrained spring system)
  zeroends = 1 ; 

  [N,junk] =size(A);
  %# find all left and right eigs
  [e,v] = eigs(A,N) ;
  [el,vl] = eigs(A',N) ;
  %# each column of e is an eig. they are unit vectors.

  omega=sqrt(diag(v)) ;

  if (zeroends) 
    %# pad out e with extra zeroes for plotting purposes.
    ep = [ zeros(1,N) ; e ; zeros(1,N) ] ;
    x0p = [ 0 , x0 , 0 ] ; 
    x1p = [ 0 , x1 , 0 ] ; 
  else
    ep = e ;    x0p = x0 ;    x1p = x1 ; 
  end
  %# project initial condition onto the eigs
  %# first find the metric. (which will be a vector of +/- 1's if A
  %# is symmetric, and less than 1's otherwise.
  for n=1:N
    metric(n) = el(:,n)' * e(:,n)  ;
  end
  metric

  %# then productify.  x0a is x0 in the eigenvector basis
  x0a  = el' * x0' ;
  x1aw = el' * x1' ;
  x0a  = x0a  ./ metric' ;
  x1aw = x1aw ./ metric' ;
  %				# recover the omega-independent coords
  x1a = x1aw ./ omega ;
  %# and obtain the omega-multipled coordinates too
  x0aw = x0a .* omega ;

  %# use y0 and y1 to denote the current state in a, and x0s and x1s in real
  %# space
  y0a = x0a ; y1a = x1aw ; %# yes, y1a should be scaled by omega
  
  %# and reconstruct the state
  reconstruct ; %# produces x0s and x1s from y0a and y1a
  
  makewindow ;
  %############################
  
  c = 3 ; %# number of columns
  ymax = 1 ; %# vertical scale
  omegamax = max(omega)  
  omegamin = min(omega)  
  vmax = ymax * ( omegamax + omegamin )  / ( 2 * sqrt(N) ) ; 
  lw = 2 ; %# linewidth
  if ( N <= 6 ) 
    blob = 10 ; %# blob size
  else
    blob = 5 ;
  end

  %#################################################
  %# make right hand column (column 3)
  thiscol =  2; 
  nright= 4;
  thisright = 0 ;
  %#
  subplot(nright,c,thiscol+c*thisright) ; %# nuffin
  delete(gca);
  thisright = thisright + 1 ; 
  %#
  subplot(nright,c,thiscol+c*thisright) ; %# projection
  delete(gca);
  subplot(nright,c,thiscol+c*thisright) ; %# 
  projplot = stem( abs(x0a), 'r.') ;
  m = max([0.1  abs( min(x0a))   max(x0a)] )*1.1 ;
  axis([0.5 N+0.5 0 m]) ;
  set(gca,'XDir','reverse') ;
  thisright = thisright + 1 ; 
  %#
  subplot(nright,c,thiscol+c*thisright) ; %# projection
  delete(gca);
  subplot(nright,c,thiscol+c*thisright) ; %# 
  proj1plot = stem (abs(x1a), 'gx' ) ; 
  %# plot( abs(x1a), 'gx' , 'LineWidth', lw,'EraseMode','xor',...
  %#		  'MarkerSize', blob , 'MarkerEdgeColor', 'g' ) ;
  m = max([0.1  abs( min(x1a))   max(x1a)] )*1.1 ;
  axis([0.5 N+0.5 0 m]) ;
  set(gca,'XDir','reverse') ;
  thisright = thisright + 1 ; 
  %#

  %#################################################
  %# make right hand column (column 2)
  thiscol =  3; 
  nright= 4;
  thisright = 0 ;
  %# 
  subplot(nright,c,thiscol+thisright*c) ; %# state
  delete(gca);
  subplot(nright,c,thiscol+thisright*c) ; %# state
  stateplot = plot( x0s, 'c-o' , 'LineWidth', lw,'EraseMode','xor',...
		   'MarkerSize', blob , 'MarkerEdgeColor', 'r' ) ;
  modifythisplot ; 
  %###############
  thisright = thisright + 1 ; 
  %#
  subplot(nright,c,thiscol+thisright*c) ; %# state-dot
  delete(gca);
  subplot(nright,c,thiscol+thisright*c) ; %# state-dot
  statedotplot = plot( x1s, 'm-o' , 'LineWidth', lw,'EraseMode','xor',...
		   'MarkerSize', blob , 'MarkerEdgeColor', 'g' ) ;
  modifythisplot ; velocityaxis ; 

  thisright = thisright + 1 ; 
  %#
  %#
  subplot(nright,c,thiscol+c*thisright) ; %# initial condn
  delete(gca);
  subplot(nright,c,thiscol+c*thisright) ; %# initial condn
  initplot = plot( x0p, 'c-o' , 'LineWidth', lw,'EraseMode','xor',...
		  'MarkerSize', blob , 'MarkerEdgeColor', 'r' ) ;
  modifythisplot ; 
  %#
  thisright = thisright + 1 ; 
  subplot(nright,c,thiscol+c*thisright) ; %# initial condn
  delete(gca);
  subplot(nright,c,thiscol+c*thisright) ; %# initial condn
  initdotplot = plot( x1p, 'm-o' , 'LineWidth', lw,'EraseMode','xor',...
		   'MarkerSize', blob , 'MarkerEdgeColor', 'g' ) ;
  
  modifythisplot ; velocityaxis ; 
  
  %##################################
  %# left column: eigs
  %##############################
  subplot(1,c,1) ; %# kill the whole column ? 
  delete(gca);
  extras = 1 ; 
  nleft = N+extras ;
  thiscol = 1 ; thisright = 0 ; 
  %#%  subplot(nright,c,thiscol+c*thisright) ; %#omega eigenvalues plot
  subplot(nleft,c,thiscol+c*thisright) ; %#omega eigenvalues plot
  delete(gca);
  subplot(nleft,c,thiscol+c*thisright) ; %# 
  initplot = plot( omega, 'b.' , 'LineWidth', lw,'EraseMode','xor',...
		  'MarkerSize', blob , 'MarkerEdgeColor', 'b' ) ;
  axis([0.5 N+0.5 0 max(omega)*1.12]) ;
  set(gca,'XDir','reverse') ;
  thisright = thisright + 1 ; 

  for n=1:N
    hold off
    %# delete this plot.
    subplot(nleft,c,(nleft-n)*c+1) ;
    delete(gca);
    subplot(nleft,c,(nleft-n)*c+1) ;
    set(gca, 'LineWidth', 3) ;
    eigplot(n) = plot( ep(:,n), 'c-o' ,...
		      'LineWidth', lw,'EraseMode','xor',...
		      'MarkerSize', blob , 'MarkerEdgeColor', 'r' ) ;
    set ( eigplot(n), 'LineWidth', 2 ) ;
    modifythisplot ; eigenaxis ; 
    hold on ; 
  end
  %# endfunction

  disp 'ready for moving eigs?'
  pause

  reps = 1 
  while reps
    for t=0:dt:T1*reps
      a = cos( omega * t )  ;
      for n=1:N
	%#      plot( a(n) * e(:,n),'y' );
	ytmp = a(n) * ep(:,n) ;
	set ( eigplot(n), 'YData', ytmp ) ;
      end
      drawnow ;
      pause (pausetime)
    end

    reps = input('repeat - how many times (0)? [initial condition next]') ;
    if ( isempty(reps) )
      reps = 0 ;
    end
  end
  
  %#  disp 'ready for moving eigs with right components?'
  %#  pause
    
  reps = 1 ; t = 0 ; 
  while reps
    for t=t:dt:t+T2 * reps
      a = cos( omega * t )  ;
      b = sin( omega * t )  ;
      y0a = x0a .* a + x1a .* b ; 
      y1a = x1aw .* a - x0aw .* b ;
      reconstruct ; 
      for n=1:N
	ytmp = y0a(n) * ep(:,n) ;
	set ( eigplot(n), 'YData', ytmp ) ;
      end
      set ( stateplot, 'YData',  x0s ) ; 
      set ( statedotplot, 'YData',  x1s ) ; 
      drawnow ;
      pause (pausetime)
    end
    reps = input('continue - how many times (0)? [give negative number to restart from t=0]') ;
    if ( isempty(reps) )
      reps = 0 ;
    end
    if ( reps<0 )
      reps = -reps ;
      t = 0 ; 
    end
  end
  
  



