function mode(A,x0,x1,dt,T1,T2,pausetime)
  %# A is a N*N matrix, which should have N real eigenvalues.
  %#  it need not be symmetric
  %# x0 and x1 are initial conditions of x and its velocity
  %# right hand column will contain
  %# the initial conditions
  %# and the reconstruction

  %# whether to show the points 0 and N+1 as having coordinate zero
  %# (good if in fact it is a wall-constrained spring system)
  zeroends = 1 ; 
  labels = 1 ; %# whether to label graphs
  %# smart plotter - 
  %# if there is coupling between ends, switch off zeroends
  [nn,mm] = size(A) ; 
  if ( nn > 3 & ( A(1,nn) ~= 0 ) )
    zeroends = 0 ;
  end

  findeigsandprojections ; 
  
  makewindow ;
  %############################
  
  c = 2 ; %# number of columns
  ymax = 1 ; %# vertical scale
  omegamax = max(omega)  
  omegamin = min(omega)  
  vmax = ymax * ( omegamax + omegamin )  / ( 2 * sqrt(N) ) ; 
  lw = 2 ; %# linewidth
  if ( N <= 6 ) 
    blob = 10 ; %# blob size
  else
    blob = 5 ;
  end
  smallblob = 5 ; 

  %#################################################
  %# make right hand column (column 3)
  thiscol =  2; 
  nright= 4;
  thisright = 0 ;

  %#################################################
  %# make right hand column (column 2)
  thiscol =  2; 
  nright= 6;
  thisright = 0 ;
  %# 
  subplot(nright,c,thiscol+thisright*c) ; %# state
  delete(gca);
  subplot(nright,c,thiscol+thisright*c) ; %# state
  stateplot = plot( x0s, 'c-o' , 'LineWidth', lw,'EraseMode','xor',...
		   'MarkerSize', blob , 'MarkerEdgeColor', 'r' ) ;
  if labels
    ylabel('x(t)') ;
  end
  modifythisplot ; 
  %###############
  thisright = thisright + 1 ; 
  %#
  subplot(nright,c,thiscol+thisright*c) ; %# state-dot
  delete(gca);
  subplot(nright,c,thiscol+thisright*c) ; %# state-dot
  statedotplot = plot( x1s, 'm-o' , 'LineWidth', lw,'EraseMode','xor',...
		   'MarkerSize', blob , 'MarkerEdgeColor', 'g' ) ;
  modifythisplot ; velocityaxis ; 
  if labels
    ylabel('dx/dt(t)') ;
  end

  thisright = thisright + 1 ; 
  %#
  %#
  subplot(nright,c,thiscol+c*thisright) ; %# initial condn
  delete(gca);
  subplot(nright,c,thiscol+c*thisright) ; %# initial condn
  initplot = plot( x0p, 'c-o' , 'LineWidth', lw,'EraseMode','xor',...
		  'MarkerSize', blob , 'MarkerEdgeColor', 'r' ) ;
  if labels
    ylabel('x(0)') ;
  end
  modifythisplot ; 
  %#
  thisright = thisright + 1 ; 
  subplot(nright,c,thiscol+c*thisright) ; %# initial condn
  delete(gca);
  subplot(nright,c,thiscol+c*thisright) ; %# initial condn
  initdotplot = plot( x1p, 'm-o' , 'LineWidth', lw,'EraseMode','xor',...
		   'MarkerSize', blob , 'MarkerEdgeColor', 'g' ) ;
  if labels
    ylabel('dx/dt(0)') ;
  end
  
  modifythisplot ; velocityaxis ; 
  thisright = thisright + 1 ;
  drawnow ;
  
  subplot(nright,c,thiscol+c*thisright) ; %# projection
  delete(gca);
  subplot(nright,c,thiscol+c*thisright) ; %# 
  projplot = stem( abs(x0a), 'r.') ;
  if labels
    ylabel('{x_a(0)}') ;
  end
  abs(x1a)
  abs(x0a)
  m = max([0.1  abs( min(real(x0a)))   max(real(x0a))] )*1.1 ;
  axis([0.5 N+0.5 0 m]) ;
  set(gca,'XDir','reverse') ;
  thisright = thisright + 1 ; 
  %#
  subplot(nright,c,thiscol+c*thisright) ; %# projection
  delete(gca);
  subplot(nright,c,thiscol+c*thisright) ; %# 
  proj1plot = stem (abs(x1a), 'gx' ) ; 
  %# plot( abs(x1a), 'gx' , 'LineWidth', lw,'EraseMode','xor',...
  %#		  'MarkerSize', blob , 'MarkerEdgeColor', 'g' ) ;
  m = max([0.1  abs( min(real(x1a)))   max(real(x1a))] )*1.1 ;
  axis([0.5 N+0.5 0 m]) ;
  if labels
    ylabel('{dx_a/dt(0)}') ;
  end
  set(gca,'XDir','reverse') ;
  thisright = thisright + 1 ; 
  %#

  %##################################
  %# left column: eigs
  %##############################
  subplot(1,c,1) ; %# kill the whole column ? 
  delete(gca);
  inversefraction = 5 ;%# 1/(this) is taken up by omegas
  if ( N > 5)
    extras = round(N/(inversefraction-1)) ; %# N/3 makes it be a quarter of the height.
  else
    extras = 1 ;
  end
  thiscol = 1 ; thisright = 0 ;
  if ( extras == 1  )
    nleft = N+extras ;
  else
    nleft = inversefraction ;
  end
  subplot(nleft,c,thiscol+c*thisright) ; %#omega eigenvalues plot
  delete(gca);
  subplot(nleft,c,thiscol+c*thisright) ; %# 
  initplot = plot( real(omega), 'bo' , 'LineWidth', lw,'EraseMode','xor',...
		  'MarkerSize', smallblob , 'MarkerEdgeColor', 'b' ) ;
  axis([0.5 N+0.5 0 max(omega)*1.12]) ;
  if labels
    title('eigenfrequencies') ;
%#    ylabel('eigenfrequencies') ;
  end
  set(gca,'XDir','reverse') ;

  %# restore standard figure size
  thisright = thisright + extras ; 
  nleft = N+extras ;

  for n=1:N
    hold off
    %# delete this plot.
    subplot(nleft,c,(nleft-n)*c+1) ;
    delete(gca);
    subplot(nleft,c,(nleft-n)*c+1) ;
    if labels & (n==1)
      title('normal modes') ;
      %#    ylabel('eigenfrequencies') ;
    end
    set(gca, 'LineWidth', 3) ;
    eigplot(n) = plot( ep(:,n), 'c-o' ,...
		      'LineWidth', lw,'EraseMode','xor',...
		      'MarkerSize', blob , 'MarkerEdgeColor', 'r' ) ;
    set ( eigplot(n), 'LineWidth', 2 ) ;
    modifythisplot ; eigenaxis ; 
    hold on ; 
  end
  %# endfunction

  disp 'ready for moving eigs?'
  pause

  reps = 1 ;
  while reps
    for t=0:dt:T1*reps
      a = cos( omega * t )  ;
      for n=1:N
	set ( eigplot(n), 'YData',  a(n) * ep(:,n) ) ;
      end
      drawnow ;
      pause (pausetime)
    end

    reps = input('repeat - how many times (0)? [initial condition next]') ;
    if ( isempty(reps) )
      reps = 0 ;
    end
  end
  
  %#  disp 'ready for moving eigs with right components?'
  %#  pause
    
  reps = 1 ; t = 0 ; 
  while reps
    for t=t:dt:t+T2 * reps
      a = cos( omega * t )  ;
      b = sin( omega * t )  ;
      y0a = x0a .* a + x1a .* b ; 
      y1a = x1aw .* a - x0aw .* b ;
      reconstruct ; 
      for n=1:N
	ytmp = y0a(n) * ep(:,n) ;
	set ( eigplot(n), 'YData', ytmp ) ;
      end
      set ( stateplot, 'YData',  x0s ) ; 
      set ( statedotplot, 'YData',  x1s ) ; 
      drawnow ;
      pause (pausetime)
    end
    reps = input('continue - how many times (0)? [give negative number to restart from t=0]') ;
    if ( isempty(reps) )
      reps = 0 ;
    end
    if ( reps<0 )
      reps = -reps ;
      t = 0 ; 
    end
  end
  
  



