function vary(M0,K0,M1,K1,x0,x1,dt,pausetime,T,padpausetime,dtpad,Tpad)
  %# plot the eigenvectors and eigenvalues as we change M from M to M1
  %# and K to K1.
  %# A is a N*N matrix, which should have N real eigenvalues.
  %#  it need not be symmetric
  %# x0 and x1 are initial conditions of x and its velocity
  %# right hand column will contain
  %# the initial conditions
  %# and the reconstruction
  %# T is the amount of realtime to elapse (default is zero, so that
  %# the eigs do not move.

  %# whether to show the points 0 and N+1 as having coordinate zero
  %# (good if in fact it is a wall-constrained spring system)
  zeroends = 1 ;

  firsttime = 1 ; 
  makewindow ;
  %############################

  ifcoupledoffzeroends ;

  while (dt>0)
    columns=0; omegahistory=[] ; thistory=[] ; 
    
    for t=0:dt:1
      columns = columns + 1 ;
      M=t*M1+(1-t)*M0 ; 
      K=t*K1+(1-t)*K0 ; 
      MI= inv(M) ;
      A=MI*K ;
      
      findeigsandprojections ; %# this ends by doing 'reconstruct'
      omegahistory (:,columns) = omega ; 
      thistory (1,columns) = t ; 
      
      if(firsttime)
	firsttime = 0 ; 
	c = 2 ; %# number of columns
	ymax = 1 ; %# vertical scale
	omegamax = max(omega)  
	omegamin = min(omega)  
	vmax = ymax * ( omegamax + omegamin )  / ( 2 * sqrt(N) ) ; 
	lw = 2 ; %# linewidth
	if ( N <= 6 ) 
	  blob = 10 ; %# blob size
	else
	  blob = 5 ;
	end
	
	%#################################################
	%# make right hand column (column 2)
	thiscol =  2; 
	nright= 1;
	thisright = 0 ;
	%# 
	subplot(nright,c,thiscol+thisright*c) ; %# state
	delete(gca);
	subplot(nright,c,thiscol+thisright*c) ; %# state
	hold on
	for n =1:N
	  perturbplot(n) = plot( omegahistory(n,:),thistory, 'b-*' );
	  %# ,'EraseMode','xor') ;
	  set ( perturbplot(n) , 'YData', omegahistory(n,:) ) ; 
	  set ( perturbplot(n) , 'XData', thistory ) ; 
	end
	axis([-0.1 1.1 0 max(omega)*1.42]) ;
	drawnow;

	%###############
	
	thisright = thisright + 1 ; 
	%#
	otherstuff = 0 ; 
	if (otherstuff) 
	  %#
	  subplot(nright,c,thiscol+c*thisright) ; %# initial condn
	  delete(gca);
	  subplot(nright,c,thiscol+c*thisright) ; %# initial condn
	  initplot = plot( x0p, 'c-o' , 'LineWidth', lw,'EraseMode','xor',...
			  'MarkerSize', blob , 'MarkerEdgeColor', 'r' ) ;
	  modifythisplot ; 
	  %#
	  thisright = thisright + 1 ; 
	  subplot(nright,c,thiscol+c*thisright) ; %# initial condn
	  delete(gca);
	  subplot(nright,c,thiscol+c*thisright) ; %# initial condn
	  initdotplot = plot( x1p, 'm-o' , 'LineWidth', lw,'EraseMode','xor',...
			     'MarkerSize', blob , 'MarkerEdgeColor', 'g' ) ;
	  
	  modifythisplot ; velocityaxis ; 
	  thisright = thisright + 1 ; 
	  
	  subplot(nright,c,thiscol+c*thisright) ; %# projection
	  delete(gca);
	  subplot(nright,c,thiscol+c*thisright) ; %# 
	  projplot = stem( abs(x0a), 'r.') ;
	  m = max([0.1  abs( min(x0a))   max(x0a)] )*1.1 ;
	  axis([0.5 N+0.5 0 m]) ;
	  set(gca,'XDir','reverse') ;
	  thisright = thisright + 1 ; 
	  %#
	  subplot(nright,c,thiscol+c*thisright) ; %# projection
	  delete(gca);
	  subplot(nright,c,thiscol+c*thisright) ; %# 
	  proj1plot = stem (abs(x1a), 'gx' ) ; 
	  %# plot( abs(x1a), 'gx' , 'LineWidth', lw,'EraseMode','xor',...
	  %#		  'MarkerSize', blob , 'MarkerEdgeColor', 'g' ) ;
	  m = max([0.1  abs( min(x1a))   max(x1a)] )*1.1 ;
	  axis([0.5 N+0.5 0 m]) ;
	  set(gca,'XDir','reverse') ;
	  thisright = thisright + 1 ; 
	  %#
	end 
	%##################################
	%# left column: eigs
	%##############################
	subplot(1,c,1) ; %# kill the whole column ? 
	delete(gca);
	extras = 1 ; 
	nleft = N+extras ;
	thiscol = 1 ; thisright = 0 ; 
	%#%  subplot(nright,c,thiscol+c*thisright) ; %#omega eigenvalues plot
	subplot(nleft,c,thiscol+c*thisright) ; %#omega eigenvalues plot
	delete(gca);
	subplot(nleft,c,thiscol+c*thisright) ; %#
	%# 'EraseMode','xor',...
	omegaplot = plot( omega, 'b.' , 'LineWidth', lw,...
			 'MarkerSize', blob , 'MarkerEdgeColor', 'b' ) ;
	axis([0.5 N+0.5 0 max(omega)*1.42]) ;
	set(gca,'XDir','reverse') ;
	thisright = thisright + 1 ; 
	drawnow ;
	
	for n=1:N
	  hold off
	  %# delete this plot.
	  subplot(nleft,c,(nleft-n)*c+1) ;
	  delete(gca);
	  subplot(nleft,c,(nleft-n)*c+1) ;
	  eigplot(n) = plot( ep(:,n), 'c-o' ,...
			    'EraseMode','xor',...
			    'LineWidth', lw,...
			    'MarkerSize', blob , 'MarkerEdgeColor', 'r' ) ;
	  set ( eigplot(n), 'LineWidth', 2 ) ;
	  modifythisplot ; eigenaxis ; 
	  hold on ; 
	end
	drawnow ;

	%# quick show.................
	%# add in an extra period at the beginning during which the wobbly eigs are
	%# shown
	repeats = 1 ; 
	while (repeats*Tpad>0) 
	  for t=-repeats:dtpad:0
	    a = cos( omega * t * Tpad )  ;
	    for n=1:N
	      set ( eigplot(n), 'YData',  a(n) * ep(:,n) ) ;
	    end
	    drawnow ;
	    pause (padpausetime)
	  end
	  repeats = input('repeat how many times (initial eig wobble)?') ;
	  if ( isempty(repeats) )
	    repeats = 0 ;
	  end
	end
	%# end if firsttime
	
      else
	%# update eigs (if T = 0 then the amplitude is fixed at 1)
	a = cos( omega * t * T )  ;
	for n=1:N
	  set ( eigplot(n), 'YData',  a(n) * ep(:,n) ) ;
	  set ( perturbplot(n) , 'YData', omegahistory(n,:) ) ; 
	  set ( perturbplot(n) , 'XData', thistory ) ; 
	end
	set ( omegaplot , 'YData', omega ) ; 
	drawnow ;
	if (otherstuff) 
	  set ( projplot , 'YData',  abs(x0a) ) ; 
	  set ( proj1plot, 'YData',  abs(x1a) ) ; 
	end
      end %# endif
      drawnow ;
      pause (pausetime)
    end

    %# add in an extra period at the end during which the wobbly eigs are
    %# shown
    repeats = 1 ; 
    while ((repeats*Tpad)>0)
      for t=t:dtpad:t+repeats
	a = cos( omega * t * Tpad )  ;
	for n=1:N
	  set ( eigplot(n), 'YData',  a(n) * ep(:,n) ) ;
	end
	drawnow ;
	pause (padpausetime)
      end
      repeats = input('repeat how many times (final eig wobble only)?') ;
      if ( isempty(repeats) )
	repeats = 0 ;
      end
    end

    dt
    dt = input('what value for dt do you want for repeat of whole show?') ;
    if ( isempty(dt) )
      dt = 0 ;
    end
  end %# endwhile
  
  
  
  
