%
% demo the simulate and forbit
% functions
%
% three particles in 2d
%
%# note that if_ p=1 and x=1 then you have a circular orbit
%# bear in mind the T^2 R^3 rule, and p scales as R/T
%# so need p = R^{-1/2}
%
%# related files: forbit for the gradient calculation
%# the variables p7 etc are defined in pictreudefns
%#
%# NB dT is the time step of underlying simulation 
%# and Tperiod is the time taken 
%# between screen renderings. 

while 1
choice = menu('Inverse-square orbits',...
	      '1: 2 orbiting particles',...
	      '2: 2 circular, radial kick 10%',...
	      '3: 3 incoming, attractive',...
	      '4: 3 incoming, repulsive, slow',...
	      '5: 3 incoming, repulsive, fast',...
	      '6: 3 body system',...
	      '7: 3 body fun',...
	      '8: (2 circular)',...
	      '9: slingshot, perfect',...
	      '10: slingshot, right',...
	      '11: slingshot, double encounter',...
	      '12: slingshot, no gravity 1-2',...
	      '13: moon in orbit',...
	      '14: moon in elliptical orbit',...
	      '15: unstable moon',...
	      '16: dying moon',...
	      '17: L5',...
	      '18: L5 perturbed, mJ=.2',...
	      '19: L5 pertd(p), mJ=.01',...
	      '20: L5 pertd more(p), mJ=.01',...
	      '21: L5 pertd(x), mJ=.01',...
	      '22: Like 2, kick along 2%',...
	      '23: Like 2, kick back 2%',...
	      '24: Like 2, kick in 2%',...
	      '25:',...
	      '26:',...
	      '27:',...
	      'continue',...
	      'tweak',...
	      'quit');

    junk = ...
	struct ( 'repulsive',  0 , ...
		'threebody', 0 ,...
		'jupiter', 0.1 ,...
		'viewall' , 1  , ...
		'refresh' , 1  , ...
		'xmax', 5.2    , ...
		'pmax', 1.0 , ...
		'fmax', 0.64 , ...
		'Kmax', 0.5 , ...
		'Vmax', 0.6 , ...
		'Hmin', -0.6 ,...
		'Hmax', 0.0 , ...
		'Tperiod', 0.2 , ...
		'wait', 0 , ...
		'scale' , 0 ...
		) ;
    slowv = [0.84,0] ;
    fastv = [2,0] ;
switch choice
  case 1,
    x=[3 3 ;  4 4] ;
    p=[-0.24,0.24; -0.24 0.24] ;
    junk.wait = 1 ;
    %# illustrates elliptical motion and what it looks like from earth pov
  case 2,
    junk.wait = 1 ;
    x=[4 0 ;  4 0] ;
    p=[-0.2,0.4;  -0.19 0.4] ;%# slight retardation: in this case green gets ahead
    p=[0,0.44;  0.04 0.44] ;%# slight outward boost: green lags behind
    %# the following label is corerct for either ^ or V
    disp 'green has a 10% outward kick, so has greater energy, same l'
    %#  circular orbits
    p=[0,0.5 ;  0.05 0.5] ;%
  case 22,
    disp 'green has a 2% onward kick, so has greater energy, bigger l'
    x=[4 0 ;  4 0] ;
    p=[0,0.5 ;  0 0.51] ;%
  case 23,
    disp 'green has a 2% backward kick'
    x=[4 0 ;  4 0] ;
    p=[0,0.5 ;  0 0.49] ;%
  case 24,
    disp 'green has a 2% inward kick'
    x=[4 0 ;  4 0] ;
    p=[0,0.5 ;  -0.01 0.5] ;%
%    disp 'green has a 10% inward kick'
%    p=[0,0.5 ;  -0.05 0.5] ;%
  case 25,
    disp 'green is out by a little and in circular orbit'
    x=[4 0 ;  4.1 0] ;
    p=[0,0.5 ;  0 1.0/sqrt(4.1)] ;%
  case 26,
    disp 'green is out and has identical velocity'
    x=[4 0 ;  4.1 0] ;
    p=[0,0.5 ; 0 0.5] ;%
  case {3,4},
    x=[-5 0.5 ; -5 1.5; -5 3 ] ;
    p=[slowv;slowv;slowv];
  case 5,
    x=[-5 0.5 ; -5 1.5; -5 3 ] ;
    p=[fastv;fastv;fastv];
  case 6, %# threebody system mimicing 1 0, 0 1 innner planet living almost independently of jupiter
    %# orbit of jupiter is not quite circular because msun is not inf.
    x=[4   0 ;  0.4   0] ;
    p=[0  0.4;  0   0.9] ;%
    junk.threebody=2 ;
    junk.jupiter = 0.2 ;
  case 7, %# slingshot threebody system, lots of exciting stuff happens, depending on dT sensitively
    x=[1 0 ;  2 0] ;
    p=[0,1 ;  0.0 0.6] ;%
    junk.threebody=2 ;
    junk.jupiter = 0.01 ; 
  case 8, %# two perfect circular orbits
    x=[1 0 ;  4 0] ;
    p=[0,1 ;  0.0 0.5] ;%
    junk.threebody=2 ;
    junk.jupiter = 0.0000001 ;
  case 9, %# slingshot threebody system, lots of interactions, though not a clear hyperbola
    junk.threebody=2 ;
    Th=-1.2;
    x=[4*cos(Th) 4*sin(Th) ;  1 0] ;
    p=[0.5*[-sin(Th) cos(Th)] ;  0.0 1.255] ;% beautiful!
    junk.jupiter=0.005 ;
    junk.jupiter=0.01 ;
    dT = 0.08 ; T = 200 ; 
    %# override the above for development purposes: 
    %#  to get to radius 4, need v = vE*sqrt(2/(1+Re/Rj))
    %# a = 5, cf a = 8, so time to get round is a^{3/2}
    %# i.e. in time that 5 goes through 1.5 orbits, mr 8 does
    %# 1.5*(5/8)^1.5 
    Th=2*3.141592* 1.5* (5.0/8.0)^1.5 + 0.1 ;
    Th=2*3.141592* 0.5* (5.0/8.0)^1.5 - 0.031 ; %# detuning parameter
%# 0.3 gives very late arrival. 0.03 seems to hit head on.
%#  0.0 gives nice close hyperbola. requires dT=0.0005
%#  -0.03 gives a slightly-off-tartget impact, nice hyperbola still when dT=0.003.
%#    Th=2*3.141592* 0.5* (5.0/8.0)^1.5  ;
%# this is an excellent slingshot now!
    x=[-4*cos(Th) -4*sin(Th) ;  -1 0] ;
    p=[-0.5*[-sin(Th) cos(Th)] ;  0.0 -sqrt(2/(1+1.0/4.0))];
    junk.jupiter=0.001 ;
    T = 42 ; dT = 0.002 ; 
    junk.Tperiod = 0.03 ;
    junk.viewall = 0 ; 
  case 10, %# slingshot right side, perfect hit, rehit!!
    Th=1.4 ;
    x=[4*cos(Th) 4*sin(Th) ;  1 0] ;
    p=[0.5*[-sin(Th) cos(Th)] ;  0.0 1.27];
    junk.threebody=2 ;
    junk.jupiter=0.01 ;
    T = 300 ; dT = 0.08 ; 
  case 11, %# slingshot right side, perfect hit, no rehit, energy lost on subsequent interactions
    Th=1.4 ;
    x=[4*cos(Th) 4*sin(Th) ;  1 0] ;
    p=[0.5*[-sin(Th) cos(Th)] ;  0.0 1.271];
    junk.threebody=2 ;
    junk.jupiter=0.01 ;
    T = 200 ; dT = 0.08 ; 
  case 12, %# slingshot right side but no mass (just as in 10)
    Th=1.4 ;
    x=[4*cos(Th) 4*sin(Th) ;  1 0] ;
    p=[0.5*[-sin(Th) cos(Th)] ;  0.0 1.27];
    T = 100 ;  dT = 0.08 ;
  case 13, %# moon in orbit
    x=[ 4 0     ; 4.04 0 ] ; % make orbit radius 1/100
    p=[ 0.0 0.5 ; 0 1.0 ] ;% so p is same?
    dT = 0.01 ; T = 100 ;
    junk.jupiter=0.01 ; 
    junk.threebody=2 ;
    junk.viewall = 0 ; 
  case 14, %# moon in orbit 2
    x=[ 4 0     ; 4.04 0 ] ; 
    p=[ 0.0 0.5 ; 0 1.1 ] ;% p = 1.05 was a bit dull
    dT = 0.01 ; T = 100 ;
    junk.jupiter=0.01 ; 
    junk.threebody=2 ;
    junk.viewall = 0 ; 
  case 15, %#  nice elliptical unstable orbit
    %# results depend on dT?
    x=[ 4 0     ; 4.4 0 ] ; 
    p=[ 0.0 0.5 ; 0  0.55 ] ;
    dT = 0.002 ; T = 100 ;
    junk.jupiter=0.01 ; 
    junk.threebody=2 ;
    junk.viewall = 2 ; 
  case 16, %# nice falling moon
    x=[ 4 0     ; 4.6 0 ] ; 
    p=[ 0.0 0.5 ; 0  0.575 ] ;
    dT = 0.004 ; T = 100 ;
    junk.jupiter=0.01 ; 
    junk.threebody=2 ;
    junk.viewall = 2 ; 
  case 17, %# L5 - demonstrates stable
    junk.threebody=2 ;
    junk.viewall = 4 ;
    junk.Tperiod = 0.1;
    junk.jupiter=0.2; %# change back to 0.2
    x=[ 4 0     ; 2     3.4641  ] ;  %# these are the coordinates if Msun=infinite
    p=[ 0.0 0.5 ; -0.4330 0.25   ] ; %# which we now overwrite.
    p(1,:) = makecircularp( x(1,:) , junk.jupiter ) ;
    [x(2,:),p(2,:)] = maketrojan( x(1,:) , p(1,:) , junk.jupiter ) ;
    
    dT = 0.1 ; T = 50 ; 
  case 18, %# L5, perturbed - shown to be unstable, and nice mess!
    %# fantastic, it even reverses direction at about 190 (for dT=0.01, anyway)
    junk.threebody=2 ;
    junk.viewall = 4 ;
    junk.Tperiod = 0.1;
    junk.jupiter=0.2; 
    x=[ 4 0     ; 2     3.4641  ] ;  %# these are the coordinates if Msun=infinite
    p=[ 0.0 0.5 ; -0.4330 0.25   ] ; %# which we now overwrite.
    p(1,:) = makecircularp( x(1,:) , junk.jupiter ) ;
    [x(2,:),p(2,:)] = maketrojan( x(1,:) , p(1,:) , junk.jupiter ) ;
    disp 'x(2) displaced by 1 percent away from the sun' 
    x(2,:) = x(2,:)*1.01 ; %# perturb a bit
    
    dT = 0.05 ; T = 180 ; 
  case 19, %# L5, p perturbed
    junk.threebody=2 ; %# appears stable?, does little figure-8-ish orbit
    junk.viewall = 4 ;
    junk.Tperiod = 0.2;
    junk.jupiter=0.01; 
    x=[ 4 0     ; 2     3.4641  ] ;  %# these are the coordinates if Msun=infinite
    p=[ 0.0 0.5 ; -0.4330 0.25   ] ; %# which we now overwrite.
    p(1,:) = makecircularp( x(1,:) , junk.jupiter ) ;
    [x(2,:),p(2,:)] = maketrojan( x(1,:) , p(1,:) , junk.jupiter ) ;
    p(2,:) = p(2,:)*1.02 ; %# perturb a bit. 1.02 is stable for at least 600.
    disp 'p(2) perturbed by 2 percent'
    dT = 0.2 ; T = 400 ; %# results for 0.05 and 0.005 seem same
  case 20, %# L5, p perturbed more
    %# ends in an unslignshot, drop to the sun.
    junk.threebody=2 ; %# appears stable for a bit but goes wild and pretty
    junk.viewall = 4 ;
    junk.Tperiod = 0.2;
    junk.jupiter=0.01; 
    x=[ 4 0     ; 2     3.4641  ] ;  %# these are the coordinates if Msun=infinite
    p=[ 0.0 0.5 ; -0.4330 0.25   ] ; %# which we now overwrite.
    p(1,:) = makecircularp( x(1,:) , junk.jupiter ) ;
    [x(2,:),p(2,:)] = maketrojan( x(1,:) , p(1,:) , junk.jupiter ) ;
    disp 'p(2) perturbed by 3 percent'
    p(2,:) = p(2,:)*1.03 ; %# perturb a bit 1.03 good (unstable), 1.026 stable?? 1.028 unstable
    
    dT = 0.05 ; T = 340 ; %# results for 0.05 and 0.005 seem same
  case 21, %# L5, perturbed - smaller mass jupiter, otherwise same as 18
    junk.threebody=2 ; %# appears stable?, does little figure-8-ish orbit
    junk.viewall = 4 ;
    junk.Tperiod = 0.2;
    junk.jupiter=0.01; 
    x=[ 4 0     ; 2     3.4641  ] ;  %# these are the coordinates if Msun=infinite
    p=[ 0.0 0.5 ; -0.4330 0.25   ] ; %# which we now overwrite.
    p(1,:) = makecircularp( x(1,:) , junk.jupiter ) ;
    [x(2,:),p(2,:)] = maketrojan( x(1,:) , p(1,:) , junk.jupiter ) ;
    disp 'x(2) displaced by 1 percent away from the sun' 
    x(2,:) = x(2,:)*1.02 ; %# perturb a bit
    %# define good viewpoint (not used, see viewall instead)
    junk.zoomview = [x(2,:)*0.9,x(2,:)*1.1]-[x(1,:),x(1,:)] ;
    
    dT = 0.05 ; T = 400 ; %# results for 0.05 and 0.005 seem same
    %# see earlier for other cases
  case 27,
    choice = 89 ;                               
    disp 'continuing'   ;
    junk.refresh = 0 ; 
  case {28},
    choice = 99 ;
    disp 'tweak menu' ; 
  otherwise
    disp 'bye'
    break
end
%# is the potential repulsive?
switch choice
  case {5,4},
    junk.repulsive = 1 ;
end
%# how long should it last?
switch choice
  case {2,22,23,24,25,26}
    T=200 ; 
  case {1,6,7,8}
    T=100 ; 
  case {3,4}
    T=20 ;
  case {5}
    T=7 ;
end
%# what display sizes wanted?
switch choice
  case {1,2,22,23,24,25,26}
    junk.xmax=5.2    ;
    junk.pmax=1.0 ;
    junk.fmax=0.64 ;
    junk.Kmax = 0.5 ;
    junk.Vmax = 0.6 ;
    junk.Hmin = -junk.Vmax ;
    junk.Hmax = 0.0 ;
    junk.scale = 0 ;

  case {6,7}
    junk.xmax=5    ;
    junk.pmax=1.1 ;
    junk.fmax=0.74 ;
    junk.Kmax = 0.5 ;
   junk.Vmax = 1 ;
    junk.Hmin = -0.6 ;
    junk.Hmax = 0.0 ;
    junk.scale = 0 ;

  case {8,9,10,11,12,13}
    junk.xmax=7.2    ;
    junk.pmax=1.5 ;
    junk.fmax=0.64 ;
    junk.Kmax = 0.5 ;
    junk.Vmax = 1.6 ;
    junk.Hmin = -junk.Vmax ;
    junk.Hmax = 0.0 ;
    junk.scale = 0 ;

  case {3}
    junk.xmax=5.2    ;
    junk.pmax=1.0 ;
    junk.fmax=0.164 ;
    junk.Kmax = 1.5 ;
    junk.Vmax = 1.6 ;
    junk.Hmax = 0.0 ;
    junk.Hmin = -junk.Vmax ;
    junk.scale = 0 ;
  case {4}
    junk.xmax=5.2    ;
    junk.pmax=1.0 ;
    junk.fmax=0.164 ;
    junk.Kmax = 0.1 ;
    junk.Vmax = 0.16 ;
    junk.Hmax = 0.0 ;
    junk.Hmin = -junk.Vmax ;
    junk.scale = 0 ;
  case {5}
    junk.xmax=5.2    ;
    junk.pmax=1.0 ;
    junk.fmax=0.164 ;
    junk.Kmax = 1 ;
    junk.Vmax = 1 ;
    junk.Hmax = 0.0 ;
    junk.Hmin = -junk.Vmax ;
    junk.scale = 0 ;
end
%# what is the duration of the steps dT in simulation , and 
%# what is the duration between renderings Tperiod?
switch choice
  case {1,2,22,23,24,25,26}
    dT=0.01 ;
    junk.Tperiod = 1;
    q1 = 0 ; 
  case {6}
    dT=0.01 ;
    junk.Tperiod = 0.4;
    q1 = 0 ; 
  case {8}
    dT=0.02 ;
    junk.Tperiod = 1;
    q1 = 2 ; 
  case 7,
    dT=0.005 ;
%#    junk.Tperiod = 1;
    q1 = 2 ; 
  case {3,4}
    dT=0.003 ;
    junk.Tperiod = 0.3 ;
    q1 = 2 ;
  case {5}
    dT=0.003 ;
    junk.Tperiod = 0.1 ;
    q1 = 2 ;
end

switch choice
  case {1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,89},
    [x,p] = simulate(x,p,T,dT,'forbit',junk) ;
  case 99,
    tweak = menu('tweak menu (useless)' ,...
		 'x',...
		 'x,p',...
		 'x,f',...
		 'x(t)',...
		 'p',...
		 'force',...
		 'V',...
		 'K',...
		 'H',...
		 'change force law',...
		 'done' ) ;
%    switch(tweak)
%      case 1,
%	p1 = 1-p1
end

end





