function [g,V] = forbit(x,t,args)
  % returns the gradient of the potential energy for_
  % a set_ of particles in an inverse square potential
  %
  % x is allowed to be any height and width
  % height = number of particles; width= number of dimensions
  % if_ threebody=1 then the number one particle is jupiter and it attracts too.
  % but the sun does not move right.
  % if_ threebody=2 then the sun moves exactly opposite to jupiter,
  % in the right proportion. 
  
  [N,D] = size(x) ;

  %# also used in makechords.m
  if args.threebody>1
    sunfactor = -args.jupiter ;
    %# get x(sun) = -sunfactor* x(jupiter)
    xsun = sunfactor * x(1,:) ;
    r = x - ones(N,1) * xsun ;
  else
    xsun = [0 0] ;
    r = x ;
  end
  
  % find radius vector 
  r2 = sum( r'.^2 )'   ; 
  r1 = r2.^(-0.5)     ; %# inverse r
  r3 = r1.^(3)         ; %# inverse r^3

  % find the inverse square force
  if args.repulsive
    for n = 1:N
      g(n,:) = - r(n,:) * r3(n) ;
      V(n,1) =   r1(n) ; 
    end
  else
    for n = 1:N
      g(n,:) = r(n,:) * r3(n) ;
      V(n,1) = - r1(n) ; 
    end
  end
  %# include Jupiter force
  if args.threebody
    dx = x(2:N,:) - x(1,:) ; 
    r2 = sum( dx'.^2 )'   ; 
    r1 = r2.^(-0.5)     ; %# inverse r
    r3 = r1.^(3)         ; %# inverse r^3

    % find the inverse square force (assumed attractive) 
    for n = 2:N
      g(n,:) =  g(n,:) + args.jupiter * dx(n-1,:) * r3(n-1) ;
      V(n,1) =  V(n,1) - args.jupiter * r1(n-1) ; 
    end
  end
  
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% end function
  
  


