function [x,p] = simulate(x,p,T,dt,f,args);
%
% this is a general dynamics simulator
%
% simulate(x,p,T,dt,f,args)
%
% simulates the equations
%  dx/dt =  p
%  dp/dt = -f(x,t)
% using the leapfrog method
%
% in steps of dt from t=0 to T
%
% the structure args.* contains options
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[N,D] = size(x) ;
[Np,Dp] = size(p) ;
if N ~= Np | D ~=Dp
  disp ' warning, x and p different dimensions '
end

%				# see forbit.m for gradient calcn
switch args.threebody
  case 0,
    disp 'all particles are negligible-mass'
  case 1,
    disp 'planet 1 (red) has attractive mass for other planets, but has no influence on the sun'
    args.jupiter
  case 2,
    disp 'planet 1 (red) has mass:'
    args.jupiter
    disp 'relative to sun=1, and the sun is accelerated by it.'
    disp 'all other planets have negligible mass'
end
period = round(args.Tperiod/dt) ;

% initialize gradient 
t = 0 ;
findgVKH ;

picturedefns
if args.refresh
  setupfigures %# includes the creation of xwindow
end
%# if_ doplots2 below then use setupfigures2 here also
setupfigures2

if args.wait
  disp 'press key'
  pause
end

epsilon = dt ;
its = 0 ; 
for t = dt : dt : T
  p = p - epsilon * g / 2 ; % # make half-step in p
  x = x + epsilon * p     ; % # make step in w
  findgVKH ;
  %
  % plotting time
  %
  if ( mod(its,period)<1 )
    % either use doplots or doplots2 here
%    t,x,p,g ;
    doplots2 ;
  end
  p = p - epsilon * g / 2 ; % # make half-step in p
  % end of loop
  its = its + 1 ; 
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



